@@ -130,7 +130,7 @@ class ModelContainer(Container):
         return len(self)
 
 
-class SmartModel(GraphNode):
+class SmartModel(GraphNodeLazy):
     _fields_ = ['_id']
     
     def __init__(self, **kw):
